Documentation
¶
Index ¶
- Constants
- func AddFlags(a *kingpin.Application)
- func GetVersion() string
- func ParseServicePath(path string) (string, string)
- func RecvMessage(conn net.Conn) (closed bool, msgBytes []byte, msg *cellaserv.Message, err error)
- func SendMessage(conn net.Conn, msg *cellaserv.Message) error
- func SendRawMessage(conn net.Conn, msg []byte) error
- type Logger
Constants ¶
const Version = "0.1"
Variables ¶
This section is empty.
Functions ¶
func AddFlags ¶
func AddFlags(a *kingpin.Application)
AddFlags adds the flags used by this package to the Kingpin application. To use the default Kingpin application, call AddFlags(kingpin.CommandLine)
func GetVersion ¶
func GetVersion() string
func ParseServicePath ¶
ParseServicePath extracts service and identification information from a request path. Supported syntaxes: - service.method or - service/identification.method
func RecvMessage ¶
RecvMessage reads and return a cellaserv message from an open connection.
Types ¶
type Logger ¶
type Logger interface {
Debug(...interface{})
Debugln(...interface{})
Debugf(string, ...interface{})
Info(...interface{})
Infoln(...interface{})
Infof(string, ...interface{})
Warn(...interface{})
Warnln(...interface{})
Warnf(string, ...interface{})
Error(...interface{})
Errorln(...interface{})
Errorf(string, ...interface{})
Fatal(...interface{})
Fatalln(...interface{})
Fatalf(string, ...interface{})
}
Logger is the interface for loggers used in the Prometheus components.
Click to show internal directories.
Click to hide internal directories.